==> uget_1.6.2.a.orig.tar.gz: uget-1.6.2/uget-gtk/UgCategoryWidget.h <==
/*
 *
 *   Copyright (C) 2005-2010 by Raymond Huang
 *   plushuang at users.sourceforge.net
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  ---
 *
 *  In addition, as a special exception, the copyright holders give
 *  permission to link the code of portions of this program with the
 *  OpenSSL library under certain conditions as described in each
 *  individual source file, and distribute linked combinations
 *  including the two.
 *  You must obey the GNU Lesser General Public License in all respects
 *  for all of the code used other than OpenSSL.  If you modify
 *  file(s) with this exception, you may extend this exception to your
 *  version of the file(s), but you are not obligated to do so.  If you
 *  do not wish to do so, delete this exception statement from your
 *  version.  If you delete this exception statement from all source
 *  files in the program, then also delete it here.
 *
 */


#ifndef UG_CATEGORY_WIDGET_H
#define UG_CATEGORY_WIDGET_H

#include <gtk/gtk.h>
#include <UgCategory-gtk.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef struct	UgCategoryWidget_			UgCategoryWidget;

// ----------------------------------------------------------------------------
// UgCategoryWidget
//
struct UgCategoryWidget_
{
	GtkWidget*		self;		// GtkVBox

	// secondary categories
	GtkWidget*		scroll;		// (GtkScrolledWindow) for UgCategoryWidget.view
	GtkTreeView*	view;		// secondary view use UgCategoryWidget.store
	GtkTreeStore*	store;		// used by UgCategoryWidget.view (secondary view)
	GtkTreeModel*	filter;		// used by UgDownloadDialog

	// primary category
	UgCategoryGtk*	primary;
	GtkTreeView*	primary_view;			// category view

	// current (selected), maybe primary or secondary
	UgCategoryGtk*		current;
	GtkTreeView*		current_view;		// category view
	UgDownloadWidget*	current_widget;
};

void	ug_category_widget_init (UgCategoryWidget* cwidget);
void	ug_category_widget_append (UgCategoryWidget* cwidget, UgCategoryGtk* category);
void	ug_category_widget_remove (UgCategoryWidget* cwidget, UgCategoryGtk* category);
void	ug_category_widget_add_list (UgCategoryWidget* cwidget, GList*	list);
GList*	ug_category_widget_get_list (UgCategoryWidget* cwidget);
guint	ug_category_widget_n_category (UgCategoryWidget* cwidget);

// ----------------------------------------------------------------------------
// GtkTreeView for UgCategoryGtk
//
GtkTreeView*	ug_category_view_new (void);
UgCategoryGtk*	ug_category_view_get_nth (GtkTreeView* view, gint n);
UgCategoryGtk*	ug_category_view_get_cursor (GtkTreeView* view);
void			ug_category_view_set_cursor (GtkTreeView* view, gint nth, gint nth_child);
void			ug_category_view_set_icon_visible (GtkTreeView* view, gboolean visible);


#ifdef __cplusplus
}
#endif

#endif  // End of UG_CATEGORY_WIDGET_H

==> uget_1.8.0.orig.tar.gz: uget-1.8.0/uget-gtk/UgCategoryWidget.h <==
/*
 *
 *   Copyright (C) 2005-2011 by C.H. Huang
 *   plushuang.tw@gmail.com
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *  ---
 *
 *  In addition, as a special exception, the copyright holders give
 *  permission to link the code of portions of this program with the
 *  OpenSSL library under certain conditions as described in each
 *  individual source file, and distribute linked combinations
 *  including the two.
 *  You must obey the GNU Lesser General Public License in all respects
 *  for all of the code used other than OpenSSL.  If you modify
 *  file(s) with this exception, you may extend this exception to your
 *  version of the file(s), but you are not obligated to do so.  If you
 *  do not wish to do so, delete this exception statement from your
 *  version.  If you delete this exception statement from all source
 *  files in the program, then also delete it here.
 *
 */


#ifndef UG_CATEGORY_WIDGET_H
#define UG_CATEGORY_WIDGET_H

#include <gtk/gtk.h>
#include <UgCategory-gtk.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef struct	UgCategoryWidget			UgCategoryWidget;

// ----------------------------------------------------------------------------
// UgCategoryWidget
//
struct UgCategoryWidget
{
	GtkWidget*		self;		// GtkVBox

	// secondary categories
	GtkWidget*		scroll;		// (GtkScrolledWindow) for UgCategoryWidget.view
	GtkTreeView*	view;		// secondary view use UgCategoryWidget.store
	GtkTreeStore*	store;		// used by UgCategoryWidget.view (secondary view)
	GtkTreeModel*	filter;		// used by UgDownloadDialog

	// primary UgCategory, UgCategoryGtk, and GtkTreeView.
	struct
	{
		UgCategory*		category;
		UgCategoryGtk*	cgtk;
		GtkTreeView*	view;	// category view
	} primary;

	// maybe primary or secondary
	// current (selected) UgCategory, UgCategoryGtk, GtkTreeView, and UgDownloadWidget.
	struct
	{
		UgCategory*			category;
		UgCategoryGtk*		cgtk;
		GtkTreeView*		view;		// category view
		UgDownloadWidget*	widget;
	} current;

	// download column
	struct
	{
		gint			nth;		// enum UgDownloadViewColumn
		GtkSortType		order;
	} sort;
};

void	ug_category_widget_init (UgCategoryWidget* cwidget);
void	ug_category_widget_append (UgCategoryWidget* cwidget, UgCategory* category);
void	ug_category_widget_remove (UgCategoryWidget* cwidget, UgCategory* category);
void	ug_category_widget_add_list (UgCategoryWidget* cwidget, GList* list);
GList*	ug_category_widget_get_list (UgCategoryWidget* cwidget);
guint	ug_category_widget_n_category (UgCategoryWidget* cwidget);

// ----------------------------------------------------------------------------
// GtkTreeView for UgCategoryGtk
//
GtkTreeView*	ug_category_view_new (void);
UgCategory*		ug_category_view_get_nth (GtkTreeView* view, gint n);
UgCategory*		ug_category_view_get_cursor (GtkTreeView* view);
void			ug_category_view_set_cursor (GtkTreeView* view, gint nth, gint nth_child);
void			ug_category_view_set_icon_visible (GtkTreeView* view, gboolean visible);


#ifdef __cplusplus
}
#endif

#endif  // End of UG_CATEGORY_WIDGET_H
